package com.gmei

import java.io.Serializable

import com.gmei.WeafareStat.{defaultParams, parser}
import org.apache.spark.sql.{SaveMode, TiContext}
import org.apache.log4j.{Level, Logger}
import scopt.OptionParser
import com.gmei.lib.AbstractParams

object strategy_clk_imp_oldUser {

  Logger.getLogger("org.apache.spark").setLevel(Level.WARN)
  Logger.getLogger("org.apache.eclipse.jetty.server").setLevel(Level.OFF)

  case class Params(env: String = "dev"
                   ) extends AbstractParams[Params] with Serializable

  val defaultParams = Params()

  val parser = new OptionParser[Params]("Feed_EDA") {
    head("WeafareStat")
    opt[String]("env")
      .text(s"the databases environment you used")
      .action((x, c) => c.copy(env = x))
    note(
      """
        |For example, the following command runs this app on a tidb dataset:
        |
        | spark-submit --class com.gmei.WeafareStat ./target/scala-2.11/feededa-assembly-0.1.jar \
      """.stripMargin +
        s"|   --env ${defaultParams.env}"
    )
  }

  def main(args: Array[String]): Unit = {
    parser.parse(args, defaultParams).map { param =>
      GmeiConfig.setup(param.env)
      val spark_env = GmeiConfig.getSparkSession()
      val sc = spark_env._2

      val ti = new TiContext(sc)
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "diary_video")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_click")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "blacklist")
      ti.tidbMapTable(dbName = "jerry_test", tableName = "bl_device_list")
      ti.tidbMapTable(dbName = "jerry_prod", tableName = "data_feed_exposure")


      import sc.implicits._
      val stat_date = GmeiConfig.getMinusNDate(1)
      println(stat_date)
      val partition_date = stat_date.replace("-","")
      val decive_id_oldUser = sc.sql(
        s"""
           |select distinct(device_id) as decive_id
           |from online.ml_device_day_active_status
           |where active_type = '4'
           |and partition_date ='${partition_date}'
         """.stripMargin
      )
      decive_id_oldUser.show()
      decive_id_oldUser.createOrReplaceTempView("device_id_old")

      val decive_id_newUser = sc.sql(
        s"""
           |select distinct(device_id) as decive_id
           |from online.ml_device_day_active_status
           |where active_type != '4'
           |and partition_date ='${partition_date}'
         """.stripMargin
      )
      decive_id_newUser.show()
      decive_id_newUser.createOrReplaceTempView("device_id_newUser")

      val strategies = Seq("[1|2]$","[3|4]$","[5|6]$","[7|8]$")
      for (strategy <- strategies){
        val clk_count_oldUser = sc.sql(
          s"""
             |select '${stat_date}' as stat_date, count(cid_id) as get_clk_count_old
             |from data_feed_click jd inner join device_id_old
             |on jd.device_id = device_id_old.decive_id
             |where  (jd.cid_type = 'diary' or jd.cid_type = 'diary_video')
             |and jd.device_id regexp'${strategy}'
             |and jd.device_id not in (select device_id from bl_device_list)
             |and jd.device_id not in (select device_id from blacklist)
             |and jd.stat_date ='${stat_date}'
         """.stripMargin
        )
        clk_count_oldUser.show()

        val imp_count_oldUser = sc.sql(
          s"""
             |select '${stat_date}' as stat_date, count(cid_id) as get_imp_count_old
             |from data_feed_exposure je inner join device_id_old
             |on je.device_id = device_id_old.decive_id
             |where je.cid_type = 'diary'
             |and je.device_id regexp'${strategy}'
             |and je.device_id not in (select device_id from bl_device_list)
             |and je.device_id not in (select device_id from blacklist)
             |and je.stat_date ='${stat_date}'
         """.stripMargin
        )
        imp_count_oldUser.show()


        val clk_count_newUser = sc.sql(
          s"""
             |select '${stat_date}' as stat_date, count(cid_id) as get_clk_count_newUser
             |from data_feed_click jd inner join device_id_newUser
             |on jd.device_id = device_id_newUser.decive_id
             |where  (jd.cid_type = 'diary' or jd.cid_type = 'diary_video')
             |and jd.device_id regexp'${strategy}'
             |and jd.device_id not in (select device_id from bl_device_list)
             |and jd.device_id not in (select device_id from blacklist)
             |and jd.stat_date ='${stat_date}'
         """.stripMargin
        )
        clk_count_newUser.show()

        val imp_count_newUser = sc.sql(
          s"""
             |select '${stat_date}' as stat_date, count(cid_id) as get_imp_count_newUser
             |from data_feed_exposure je inner join device_id_newUser
             |on je.device_id = device_id_newUser.decive_id
             |where je.cid_type = 'diary'
             |and je.device_id regexp'${strategy}'
             |and je.device_id not in (select device_id from bl_device_list)
             |and je.device_id not in (select device_id from blacklist)
             |and je.stat_date ='${stat_date}'
         """.stripMargin
        )
        imp_count_newUser.show()

        val result = clk_count_oldUser.join(imp_count_oldUser,"stat_date")
          .join(clk_count_newUser,"stat_date")
          .join(imp_count_newUser,"stat_date")
        result.show()



      }




    }


  }

}